DecoderEvent

Enum DecoderEvent 

#[non_exhaustive]
pub enum DecoderEvent<'a> { DecodeChunk(EncodedInputChunk<'a>), SignalFrameEnd, SignalDataLoss, Flush, }
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Represents all events that can be sent to the decoder

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DecodeChunk(EncodedInputChunk<'a>)

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Submit encoded chunk for decoding



SignalFrameEnd

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Signal the end of the current frame and flush any buffered bitstream units in the parser.

You should send this event only if you need to minimize the codec parsing latency. The decoder does not require it to work.

Send this only after submitting all bitstream units belonging to a single frame. Any incomplete bitstream units buffered in the parser will be flushed and decoded, which may lead to artifacts.



SignalDataLoss

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Signal the decoder that a chunk of the bitstream was lost.

What the decoder will do depends on the set parameters::MissedFrameHandling



Flush

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Flush all frames from the decoder.

Make sure that this is done when you have the knowledge that no more frames will be coming that need to be presented before the already decoded frames.