RateControl

Enum RateControl 

pub enum RateControl {
    EncoderDefault,
    VariableBitrate {
        average_bitrate: u64,
        max_bitrate: u64,
        virtual_buffer_size: Duration,
    },
    ConstantBitrate {
        bitrate: u64,
        virtual_buffer_size: Duration,
    },
    Disabled,
}
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

The rate control algorithm to be used by the encoder.

Note: EncoderDefault is not a good default! For most implementations it is the same as specifying Disabled.

For most use cases, Vbr is the correct option

Variants



EncoderDefault

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Use the default setting of the encoder implementation.



VariableBitrate

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Variable bitrate rate control. This setting fits most use cases. The encoder will try to keep the bitrate around the average, but may increase it temporarily up to the max when necessary, in virtual_buffer_size-length windows. Bitrate is measured in bits/second.

Fields

average_bitrate: u64
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

max_bitrate: u64
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

virtual_buffer_size: Duration
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.



ConstantBitrate

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Constant bitrate rate control. This setting is for environments that are more bandwidth-constrained. The encoder will keep the bitrate at the specified value, in virtual_buffer_size-length windows. Bitrate is measured in bits/second.

Fields

bitrate: u64
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

virtual_buffer_size: Duration
👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.



Disabled

👎Deprecated since 0.3.1:

This crate has been renamed. Please migrate to gpu-video.

Rate control is turned off, frames are compressed with a constant rate. A more complicated frame will just be bigger.