pub struct EncodedInputChunk<'a> {
pub data: &'a [u8],
pub pts: Option<u64>,
}👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.
Represents a chunk of encoded video data used for decoding.
pts is the presentation timestamp – a number, which describes when the given frame
should be presented, used for synchronization with other tracks, e.g. with audio
If pts is Option::Some, it is inferred that the chunk contains bytestream that belongs to
one output frame.
If pts is Option::None, the chunk can contain bytestream from multiple consecutive
frames.
Fields
data: &'a [u8]👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.
pts: Option<u64>👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.