#[non_exhaustive]pub enum DecoderEvent<'a> {
DecodeChunk(EncodedInputChunk<'a>),
SignalFrameEnd,
SignalDataLoss,
Flush,
}This crate has been renamed. Please migrate to gpu-video.
Represents all events that can be sent to the decoder
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DecodeChunk(EncodedInputChunk<'a>)
This crate has been renamed. Please migrate to gpu-video.
Submit encoded chunk for decoding
SignalFrameEnd
This crate has been renamed. Please migrate to gpu-video.
Signal the end of the current frame and flush any buffered bitstream units in the parser.
You should send this event only if you need to minimize the codec parsing latency. The decoder does not require it to work.
Send this only after submitting all bitstream units belonging to a single frame. Any incomplete bitstream units buffered in the parser will be flushed and decoded, which may lead to artifacts.
SignalDataLoss
This crate has been renamed. Please migrate to gpu-video.
Signal the decoder that a chunk of the bitstream was lost.
What the decoder will do depends on the set parameters::MissedFrameHandling
Flush
This crate has been renamed. Please migrate to gpu-video.
Flush all frames from the decoder.
Make sure that this is done when you have the knowledge that no more frames will be coming that need to be presented before the already decoded frames.