pub struct EncoderOutputParameters {
pub idr_period: Option<NonZeroU32>,
pub rate_control: RateControl,
pub max_references: Option<NonZeroU32>,
pub profile: H264Profile,
pub quality_level: u32,
pub usage_flags: Option<EncoderUsageFlags>,
pub tuning_mode: Option<EncoderTuningMode>,
pub content_flags: Option<EncoderContentFlags>,
pub inline_stream_params: Option<bool>,
pub color_space: Option<ColorSpace>,
pub color_range: Option<ColorRange>,
}This crate has been renamed. Please migrate to gpu-video.
Parameters that describe an encoded output.
Fields
idr_period: Option<NonZeroU32>This crate has been renamed. Please migrate to gpu-video.
Number of frames between IDRs. If None, this will be set to an encoder preferred value,
or, if the encoder doesn’t provide a preferred value, to 30.
rate_control: RateControlThis crate has been renamed. Please migrate to gpu-video.
See RateControl for description of different rate control modes. The selected mode must
be supported by the device.
max_references: Option<NonZeroU32>This crate has been renamed. Please migrate to gpu-video.
Max number of references a P-frame can have. If None, this value will be set
to the max value supported by the device.
profile: H264ProfileThis crate has been renamed. Please migrate to gpu-video.
The profile must be supported by the device
quality_level: u32This crate has been renamed. Please migrate to gpu-video.
The value must be less than
EncodeH264ProfileCapabilities::quality_levels
usage_flags: Option<EncoderUsageFlags>This crate has been renamed. Please migrate to gpu-video.
A hint indicating what the encoded content is going to be used for.
Multiple flags can be combined using the | operator to indicate multiple usages.
tuning_mode: Option<EncoderTuningMode>This crate has been renamed. Please migrate to gpu-video.
A hint indicating how to tune the encoder implementation.
content_flags: Option<EncoderContentFlags>This crate has been renamed. Please migrate to gpu-video.
A hint indicating what kind of content the encoder is going to be used for.
Multiple flags can be combined using the | operator to indicate multiple usages.
inline_stream_params: Option<bool>This crate has been renamed. Please migrate to gpu-video.
Whether to prepend SPS/PPS NAL units inline before IDR frames.
If false, SPS/PPS can be retrieved separately using methods defined on the encoder.
If None, defaults to true.
color_space: Option<ColorSpace>This crate has been renamed. Please migrate to gpu-video.
Color space of the encoded output.
If None, defaults to ColorSpace::Unspecified.
color_range: Option<ColorRange>This crate has been renamed. Please migrate to gpu-video.
Color range of the encoded output.
If None, defaults to ColorRange::Limited.