pub struct EncodedOutputChunk<T> {
pub data: T,
pub pts: Option<u64>,
pub is_keyframe: bool,
}👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.
Represents a chunk of encoded video data returned by the encoder.
pts is the presentation timestamp – a number, which describes when the given frame
should be presented, used for synchronization with other tracks, e.g. with audio
Fields
data: T👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.
pts: Option<u64>👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.
is_keyframe: bool👎Deprecated since 0.3.1:
This crate has been renamed. Please migrate to gpu-video.